//******************************************************************************
// File Name            : svga_ap.v
//------------------------------------------------------------------------------
// Function             : svga_if top module
//                        
//------------------------------------------------------------------------------
// Designer             : yokomizo@himwari_co 
//------------------------------------------------------------------------------
// History
// -.-- 2010/8/5
// -.-- 2010/9/22
//******************************************************************************
module svga_ap (
  clk,
  rstb,
  da_en,
  da_r,
  da_g,
  da_b,
  vsync,
  hsync,
  led_0
  );

  input clk;
  input rstb;
  output da_en;
  output [3:0]da_r;
  output [3:0]da_g;
  output [3:0]da_b;
  output vsync;
  output hsync;
  output led_0;
  //
  reg    led_0;
  reg [25:0]     led_cnt;
   
  //
  wire in_a_da_en;
  wire [7:0]in_a_da_r;
  wire [7:0]in_a_da_g;
  wire [7:0]in_a_da_b;
  // 
  wire in_b_da_en; 
  wire [7:0]in_b_da_r;
  wire [7:0]in_b_da_g;
  wire [7:0]in_b_da_b;
  //
  wire in_c_da_en;
  wire [7:0]in_c_da_r;
  wire [7:0]in_c_da_g;
  wire [7:0]in_c_da_b;
  //
  wire in_d_da_en; 
  wire [7:0]in_d_da_r;
  wire [7:0]in_d_da_g;
  wire [7:0]in_d_da_b;
  //wire sync;
  wire tmg_sync;
  wire h_c_en;
  wire [9:0] v_c;
  wire [9:0] h_c;
   
  wire [7:0]da_r_tmp;
  wire [7:0]da_g_tmp;
  wire [7:0]da_b_tmp;
  
  wire test_mode;

  assign test_mode = 1'b0;

  assign da_r = da_r_tmp[7:4];
  assign da_g = da_g_tmp[7:4];
  assign da_b = da_b_tmp[7:4];
   
//LED_
always @ (posedge clk or negedge rstb )
if (rstb==1'b0)
  begin 
    led_cnt <= 26'b0;
    led_0 <= 1'b1;
  end
else
  if (led_cnt == 26'd40000000)
    begin
      led_cnt <= 26'b0;
       led_0 <= ~led_0;
    end
  else
    begin
       led_cnt <= led_cnt + 26'd1;
       led_0 <= led_0;
    end 



layer_a layer_a(
  .clk(    clk),        
  .rstb(     rstb),   
  .h_c_en(h_c_en),
  .v_c(v_c),
  .h_c(h_c),             
  .gen_da_en(in_a_da_en),
  .gen_da_r( in_a_da_r), 
  .gen_da_g( in_a_da_g), 
  .gen_da_b( in_a_da_b) 
);

layer_b layer_b(
  .clk(    clk),        
  .rstb(     rstb),   
  .h_c_en(h_c_en),
  .v_c(v_c),
  .h_c(h_c),             
  .gen_da_en(in_b_da_en),
  .gen_da_r( in_b_da_r), 
  .gen_da_g( in_b_da_g), 
  .gen_da_b( in_b_da_b) 
);
   
layer_c layer_c(
  .clk(    clk),        
  .rstb(     rstb),   
  .h_c_en(h_c_en),
  .v_c(v_c),
  .h_c(h_c),             
  .gen_da_en(in_c_da_en),
  .gen_da_r( in_c_da_r), 
  .gen_da_g( in_c_da_g), 
  .gen_da_b( in_c_da_b) 
);      

layer_d layer_d (
  .clk(    clk),        
  .rstb(     rstb),   
  .h_c_en(h_c_en),
  .v_c(v_c),
  .h_c(h_c),             
  .gen_da_en(in_d_da_en),
  .gen_da_r( in_d_da_r), 
  .gen_da_g( in_d_da_g), 
  .gen_da_b( in_d_da_b)
);

   
svga_if svga_if (
  .clk(         clk),           
  .rstb(        rstb),     
  .h_c_en(   h_c_en),     
  .out_hsync( hsync),   
  .out_vsync( vsync),   
  .v_c(         v_c),           
  .h_c(         h_c),  
  .in_a_da_en(  in_a_da_en),      
  .in_a_da_r(   in_a_da_r),       
  .in_a_da_g(   in_a_da_g),       
  .in_a_da_b(   in_a_da_b),      
  .in_b_da_en(  in_b_da_en),      
  .in_b_da_r(   in_b_da_r),       
  .in_b_da_g(   in_b_da_g),       
  .in_b_da_b(   in_b_da_b),      
  .in_c_da_en(  in_c_da_en),      
  .in_c_da_r(   in_c_da_r),       
  .in_c_da_g(   in_c_da_g),       
  .in_c_da_b(   in_c_da_b),      
  .in_d_da_en(  in_d_da_en),      
  .in_d_da_r(   in_d_da_r),       
  .in_d_da_g(   in_d_da_g),       
  .in_d_da_b(   in_d_da_b),       
  .out_da_r(    da_r_tmp),      
  .out_da_g(    da_g_tmp),      
  .out_da_b(    da_b_tmp),      
  .out_da_en(   da_en)        
);
   
                   
endmodule



